pub struct BraceExpander { /* private fields */ }Expand description
Brace expander
Implementations
Sourceimpl BraceExpander
impl BraceExpander
Sourcepub const fn new() -> Self
pub const fn new() -> Self
Create a new default BraceExpander with sensible options
This is the same as calling Default::default() but it is a const method
Sourcepub const fn ignore_parse_failures(self, value: bool) -> Self
pub const fn ignore_parse_failures(self, value: bool) -> Self
Ignore parse failures instead of erroring out, making the parsing stage infallible. This is how Bash behaves.
Example
let be = BraceExpander::new().ignore_parse_failures(false);
assert!(be.expand("{1...10}").is_err());
let be = be.ignore_parse_failures(true);
assert_eq!(be.expand("{1...10}").unwrap().join(" "), "{1...10}");Default: false
Sourcepub const fn interpret_backslashes(self, value: bool) -> Self
pub const fn interpret_backslashes(self, value: bool) -> Self
Interpret backslashes as a method of escaping a character as text. Enabling this makes the tokenization process fallible (fails on backslash with nothing following it).
Example
let be = BraceExpander::new().interpret_backslashes(false);
assert_eq!(be.expand("\\{a,b}").unwrap().join(" "), "\\a \\b");
let be = be.interpret_backslashes(true);
assert_eq!(be.expand("\\{a,b}").unwrap().join(" "), "{a,b}");Default: false